@@ -22,8 +22,8 @@
 #include "mboximportkernel.h"
 #include "mboximporterinfogui.h"
 
-#include <mailimporter/filtermbox.h>
-#include <mailimporter/importmailswidget.h>
+#include <MailImporter/FilterMBox>
+#include <MailImporter/ImportMailsWidget>
 #include <MailImporterAkonadi/FilterImporterAkonadi>
 
 #include <MailCommon/MailKernel>
